@@ -1,9 +1,10 @@
 """
 Description for boto3 service.
 """
-from typing import Tuple
+from typing import Literal, Tuple
 
 from mypy_boto3_builder.constants import MODULE_NAME, PYPI_NAME
+from mypy_boto3_builder.utils.strings import get_anchor_link
 
 __all__ = (
     "ServiceName",
@@ -16,6 +17,7 @@ class ServiceName:
     Description for boto3 service.
     """
 
+    LATEST = "latest"
     ESSENTIAL = (
         "ec2",
         "rds",
@@ -29,7 +31,7 @@ class ServiceName:
     def __init__(self, name: str, class_name: str) -> None:
         self.name = name
         self.class_name = class_name
-        self.boto3_version = "latest"
+        self.boto3_version = self.LATEST
 
     def __hash__(self) -> int:
         return hash(self.name)
@@ -90,12 +92,56 @@ class ServiceName:
         return self.name in self.ESSENTIAL
 
     @property
-    def doc_link(self) -> str:
+    def boto3_doc_link(self) -> str:
+        """
+        Link to boto3 docs.
+        """
         return (
             "https://boto3.amazonaws.com/v1/documentation/api/"
             f"{self.boto3_version}/reference/services/{self.boto3_name}.html#{self.class_name}"
         )
 
+    @property
+    def local_doc_link(self) -> str:
+        """
+        Link to local docs.
+        """
+        return f"https://vemel.github.io/boto3_stubs_docs/{self.module_name}/"
+
+    def get_boto3_doc_link(self, *parts: str) -> str:
+        """
+        Get link to boto3 docs with anchor.
+
+        Arguments:
+            parts -- Anchor parts
+        """
+        return ".".join([self.boto3_doc_link, *parts])
+
+    def get_doc_link(
+        self,
+        file: Literal[
+            "client",
+            "service_resource",
+            "waiters",
+            "paginators",
+            "type_defs",
+            "literals",
+        ],
+        *parts: str,
+    ) -> str:
+        """
+        Get link to local docs with anchor.
+
+        Arguments:
+            file -- HTML file name
+            parts -- Anchor parts
+        """
+        link = f"{self.local_doc_link}{file}.html"
+        if not parts:
+            return link
+        anchor = "".join([get_anchor_link(part) for part in parts])
+        return f"{link}#{anchor}"
+
 
 class ServiceNameCatalog:
     """
