@@ -13,6 +13,7 @@ from mypy_boto3_builder.structures.waiter import Waiter
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 from mypy_boto3_builder.type_annotations.type_literal import TypeLiteral
 from mypy_boto3_builder.type_annotations.type_typed_dict import TypeTypedDict
+from mypy_boto3_builder.utils.strings import is_reserved
 
 
 class ServicePackage(Package):
@@ -41,7 +42,7 @@ class ServicePackage(Package):
 
     def extract_literals(self) -> List[TypeLiteral]:
         found: Dict[str, TypeLiteral] = {}
-        for type_annotation in sorted(self.get_types()):
+        for type_annotation in sorted([*self.get_types(), *self.typed_dicts]):
             current: List[TypeLiteral] = []
             if isinstance(type_annotation, TypeTypedDict):
                 current.extend(type_annotation.get_children_literals())
@@ -55,7 +56,9 @@ class ServicePackage(Package):
 
                 old_literal = found[literal.name]
                 if not literal.is_same(old_literal):
-                    raise ValueError(f"Duplicate literal: {literal.name}")
+                    raise ValueError(
+                        f"Duplicate literal: {literal.name} {literal.children} != {old_literal.children}"
+                    )
 
         return list(sorted(found.values()))
 
@@ -76,7 +79,6 @@ class ServicePackage(Package):
 
         while discovered:
             child = discovered.pop()
-            child.replace_self_references()
             sub_typed_dicts = child.get_children_typed_dicts()
             for child_typed_dict in sorted(sub_typed_dicts):
                 child_typed_dict.stringify = True
@@ -250,7 +252,7 @@ class ServicePackage(Package):
             *(i.name for i in self.paginators),
             *(self.service_resource.get_all_names() if self.service_resource else []),
         ):
-            if name in TypeLiteral.RESERVED_NAMES:
+            if is_reserved(name):
                 raise ValueError(f"{name} is a reserved keyword")
             if name in names:
                 raise ValueError(f"Duplicate name {name}")
